## Youtube Speech Data Generator

A python library to generate speech dataset. 

<!-- NOTE - `audio.py` is highly based on [Real Time Voice Cloning](https://github.com/CorentinJ/Real-Time-Voice-Cloning/blob/master/encoder/audio.py) -->
